from typing import overload
from typing import List
from .PerExecLibrary import PerExecLibrary
from .BaseScriptContext import BaseScriptContext
from .BaseProfile import BaseProfile
from .ConfigManager import ConfigManager
from .ServiceManager import ServiceManager
from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .MethodWrapper import MethodWrapper
from .IEventListener import IEventListener
from .EventFilterer import EventFilterer
from .FJsMacros_EventAndContext import FJsMacros_EventAndContext
from .FiltererComposed import FiltererComposed
from .FiltererModulus import FiltererModulus
from .EventCustom import EventCustom


class FJsMacros(PerExecLibrary):
	"""Functions that interact directly with JsMacros or Events. 
An instance of this class is passed to scripts as the 'JsMacros' variable.
	"""

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def getProfile(self) -> BaseProfile:
		"""

		Returns:
			the JsMacros profile class. 
		"""
		pass

	@overload
	def getConfig(self) -> ConfigManager:
		"""

		Returns:
			the JsMacros config management class. 
		"""
		pass

	@overload
	def getServiceManager(self) -> ServiceManager:
		"""services are background scripts designed to run full time and are mainly noticed by their side effects.\n
		Since: 1.6.3 

		Returns:
			for managing services. 
		"""
		pass

	@overload
	def getOpenContexts(self) -> List[BaseScriptContext]:
		"""
		Since: 1.4.0 

		Returns:
			list of non-garbage-collected ScriptContext's 
		"""
		pass

	@overload
	def runScript(self, file: str) -> EventContainer:
		"""
		Since: 1.1.5 

		Args:
			file: 
		"""
		pass

	@overload
	def runScript(self, file: str, fakeEvent: BaseEvent) -> EventContainer:
		"""
		Since: 1.6.3 

		Args:
			file: 
			fakeEvent: you probably actually want to pass an instance created by FJsMacros#createCustomEvent(java.lang.String) 
		"""
		pass

	@overload
	def runScript(self, file: str, fakeEvent: BaseEvent, callback: MethodWrapper) -> EventContainer:
		"""runs a script with a eventCustom to be able to pass args\n
		Since: 1.6.3 (1.1.5 - 1.6.3 didn't have fakeEvent) 

		Args:
			file: 
			fakeEvent: 
			callback: 

		Returns:
			container the script is running on. 
		"""
		pass

	@overload
	def runScript(self, language: str, script: str) -> EventContainer:
		"""
		Since: 1.2.4 

		Args:
			language: 
			script: 
		"""
		pass

	@overload
	def runScript(self, language: str, script: str, callback: MethodWrapper) -> EventContainer:
		"""Runs a string as a script.\n
		Since: 1.2.4 

		Args:
			callback: calls your method as a Consumer String 
			language: 
			script: 

		Returns:
			the EventContainer the script is running on. 
		"""
		pass

	@overload
	def runScript(self, language: str, script: str, file: str, callback: MethodWrapper) -> EventContainer:
		"""
		Since: 1.6.0 

		Args:
			file: 
			callback: 
			language: 
			script: 
		"""
		pass

	@overload
	def runScript(self, language: str, script: str, file: str, event: BaseEvent, callback: MethodWrapper) -> EventContainer:
		"""
		Since: 1.7.0 

		Args:
			file: 
			callback: 
			language: 
			event: 
			script: 
		"""
		pass

	@overload
	def wrapScriptRun(self, file: str) -> MethodWrapper:
		"""
		Since: 1.7.0 

		Args:
			R: 
			file: 
			T: 
			U: 
		"""
		pass

	@overload
	def wrapScriptRun(self, language: str, script: str) -> MethodWrapper:
		"""
		Since: 1.7.0 

		Args:
			R: 
			T: 
			U: 
			language: 
			script: 
		"""
		pass

	@overload
	def wrapScriptRun(self, language: str, script: str, file: str) -> MethodWrapper:
		"""
		Since: 1.7.0 

		Args:
			R: 
			file: 
			T: 
			U: 
			language: 
			script: 
		"""
		pass

	@overload
	def wrapScriptRunAsync(self, file: str) -> MethodWrapper:
		"""
		Since: 1.7.0 

		Args:
			R: 
			file: 
			T: 
			U: 
		"""
		pass

	@overload
	def wrapScriptRunAsync(self, language: str, script: str) -> MethodWrapper:
		"""
		Since: 1.7.0 

		Args:
			R: 
			T: 
			U: 
			language: 
			script: 
		"""
		pass

	@overload
	def wrapScriptRunAsync(self, language: str, script: str, file: str) -> MethodWrapper:
		"""
		Since: 1.7.0 

		Args:
			R: 
			file: 
			T: 
			U: 
			language: 
			script: 
		"""
		pass

	@overload
	def open(self, path: str) -> None:
		"""Opens a file with the default system program.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 
		"""
		pass

	@overload
	def openUrl(self, url: str) -> None:
		"""
		Since: 1.6.0 

		Args:
			url: 
		"""
		pass

	@overload
	def on(self, event: str, callback: MethodWrapper) -> IEventListener:
		"""Creates a listener for an event, this function can be more efficient that running a script file when used properly.\n
		Since: 1.2.7 

		Args:
			callback: calls your method as a BiConsumer BaseEvent , EventContainer 
			event: 
		"""
		pass

	@overload
	def on(self, event: str, joined: bool, callback: MethodWrapper) -> IEventListener:
		"""Creates a listener for an event, this function can be more efficient that running a script file when used properly.\n
		Since: 1.9.0 

		Args:
			callback: calls your method as a BiConsumer BaseEvent , EventContainer 
			event: 
		"""
		pass

	@overload
	def on(self, event: str, filterer: EventFilterer, callback: MethodWrapper) -> IEventListener:
		"""Creates a listener for an event, this function can be more efficient that running a script file when used properly.\n
		Since: 1.9.1 

		Args:
			callback: calls your method as a BiConsumer BaseEvent , EventContainer 
			event: 
		"""
		pass

	@overload
	def on(self, event: str, filterer: EventFilterer, joined: bool, callback: MethodWrapper) -> IEventListener:
		"""Creates a listener for an event, this function can be more efficient that running a script file when used properly.\n
		Since: 1.9.1 

		Args:
			callback: calls your method as a BiConsumer BaseEvent , EventContainer 
			event: 
		"""
		pass

	@overload
	def once(self, event: str, callback: MethodWrapper) -> IEventListener:
		"""Creates a single-run listener for an event, this function can be more efficient that running a script file when used properly.\n
		Since: 1.2.7 

		Args:
			callback: calls your method as a BiConsumer BaseEvent , EventContainer 
			event: 

		Returns:
			the listener. 
		"""
		pass

	@overload
	def once(self, event: str, joined: bool, callback: MethodWrapper) -> IEventListener:
		"""Creates a single-run listener for an event, this function can be more efficient that running a script file when used properly.\n
		Since: 1.9.0 

		Args:
			callback: calls your method as a BiConsumer BaseEvent , EventContainer 
			event: 

		Returns:
			the listener. 
		"""
		pass

	@overload
	def off(self, listener: IEventListener) -> bool:
		"""
		Since: 1.2.3 

		Args:
			listener: 
		"""
		pass

	@overload
	def off(self, event: str, listener: IEventListener) -> bool:
		"""Removes a IEventListener from an event.\n
		Since: 1.2.3 

		Args:
			listener: 
			event: 
		"""
		pass

	@overload
	def disableAllListeners(self, event: str) -> None:
		"""Will also disable all listeners for the given event, including JsMacros own event listeners.\n
		Since: 1.8.4 

		Args:
			event: the event to remove all listeners from 
		"""
		pass

	@overload
	def disableAllListeners(self) -> None:
		"""Will also disable all listeners, including JsMacros own event listeners.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def disableScriptListeners(self, event: str) -> None:
		"""Will only disable user created event listeners for the given event. This includes listeners
created from FJsMacros#on(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) , FJsMacros#once(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) , FJsMacros#waitForEvent(java.lang.String) , FJsMacros#waitForEvent(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,java.lang.Object,java.lang.Boolean,?>) and FJsMacros#waitForEvent(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,java.lang.Object,java.lang.Boolean,?>,xyz.wagyourtail.jsmacros.core.MethodWrapper<java.lang.Object,java.lang.Object,java.lang.Object,?>) .\n
		Since: 1.8.4 

		Args:
			event: the event to remove all listeners from 
		"""
		pass

	@overload
	def disableScriptListeners(self) -> None:
		"""Will only disable user created event listeners.  This includes listeners created from FJsMacros#on(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) , FJsMacros#once(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) , FJsMacros#waitForEvent(java.lang.String) , FJsMacros#waitForEvent(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,java.lang.Object,java.lang.Boolean,?>) and FJsMacros#waitForEvent(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,java.lang.Object,java.lang.Boolean,?>,xyz.wagyourtail.jsmacros.core.MethodWrapper<java.lang.Object,java.lang.Object,java.lang.Object,?>) .\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def waitForEvent(self, event: str) -> FJsMacros_EventAndContext:
		"""
		Since: 1.5.0 

		Args:
			event: event to wait for 

		Returns:
			a event and a new context if the event you're waiting for was joined, to leave it early. 
		"""
		pass

	@overload
	def waitForEvent(self, event: str, join: bool) -> FJsMacros_EventAndContext:
		"""
		Since: 1.9.0 

		Args:
			event: event to wait for 

		Returns:
			a event and a new context if the event you're waiting for was joined, to leave it early. 
		"""
		pass

	@overload
	def waitForEvent(self, event: str, filter: MethodWrapper) -> FJsMacros_EventAndContext:
		"""
		Since: 1.5.0 [citation needed] 

		Args:
			event: 
		"""
		pass

	@overload
	def waitForEvent(self, event: str, join: bool, filter: MethodWrapper) -> FJsMacros_EventAndContext:
		"""
		Since: 1.9.0 

		Args:
			event: 
		"""
		pass

	@overload
	def waitForEvent(self, event: str, filter: MethodWrapper, runBeforeWaiting: MethodWrapper) -> FJsMacros_EventAndContext:
		"""waits for an event. if this thread is bound to an event already, this will release current lock.\n
		Since: 1.5.0 

		Args:
			filter: filter the event until it has the proper values or whatever. 
			runBeforeWaiting: runs as a Runnable , run before waiting, this is a thread-safety thing to prevent "interrupts" from going in between this and things like deferCurrentTask 
			event: event to wait for 

		Returns:
			a event and a new context if the event you're waiting for was joined, to leave it early. 
		"""
		pass

	@overload
	def waitForEvent(self, event: str, join: bool, filter: MethodWrapper, runBeforeWaiting: MethodWrapper) -> FJsMacros_EventAndContext:
		"""waits for an event. if this thread is bound to an event already, this will release current lock.\n
		Since: 1.9.0 

		Args:
			filter: filter the event until it has the proper values or whatever. 
			runBeforeWaiting: runs as a Runnable , run before waiting, this is a thread-safety thing to prevent "interrupts" from going in between this and things like deferCurrentTask 
			event: event to wait for 

		Returns:
			a event and a new context if the event you're waiting for was joined, to leave it early. 
		"""
		pass

	@overload
	def listeners(self, event: str) -> List[IEventListener]:
		"""
		Since: 1.2.3 

		Args:
			event: 

		Returns:
			a list of script-added listeners. 
		"""
		pass

	@overload
	def createEventFilterer(self, event: str) -> EventFilterer:
		"""create an event filterer. this exists to reduce lag when listening to frequently triggered events.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def createComposedEventFilterer(self, initial: EventFilterer) -> FiltererComposed:
		"""create a composed event filterer. this filterer combines multiple filterers together with and/or logic.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def createModulusEventFilterer(self, quotient: int) -> FiltererModulus:
		"""create a modulus event filterer. this filterer only let every nth event pass through.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def invertEventFilterer(self, base: EventFilterer) -> EventFilterer:
		"""inverts the base filterer's result. this checks if the base is already inverted. e.g. 'filterer == invert(invert(filterer))' would be 'true' .\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def createCustomEvent(self, eventName: str) -> EventCustom:
		"""create a custom event object that can trigger a event. It's recommended to use EventCustom#registerEvent() to set up the event to be visible in the GUI.\n
		Since: 1.2.8 

		Args:
			eventName: name of the event. please don't use an existing one... your scripts might not like that. 
		"""
		pass

	@overload
	def assertEvent(self, event: BaseEvent, type: str) -> None:
		"""asserts if 'event' is the correct type of event and convert 'event' type to target type in ts example: JsMacros.assertEvent(event, 'Service')\n
		Since: 1.9.0 

		Args:
			event: the event to assert 
			type: string of the event type 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_passive_SnowGolemEntity = TypeVar("net_minecraft_entity_passive_SnowGolemEntity")
SnowGolemEntity = net_minecraft_entity_passive_SnowGolemEntity


class SnowGolemEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: SnowGolemEntity) -> None:
		pass

	@overload
	def hasPumpkin(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the snow golem has a pumpkin on its head, 'false' otherwise. 
		"""
		pass

	@overload
	def isShearable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this snow golem can be sheared, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .IPalettedContainer import IPalettedContainer
from .IPalettedContainerData import IPalettedContainerData

T = TypeVar("T")

class MixinPalettedContainer(IPalettedContainer, Generic[T]):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getData(self) -> IPalettedContainerData:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set
from .IFontManager import IFontManager

net_minecraft_util_Identifier = TypeVar("net_minecraft_util_Identifier")
Identifier = net_minecraft_util_Identifier


class MixinFontManager(IFontManager):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getFontList(self) -> Set[Identifier]:
		pass

	pass





from typing import overload
from .EventFilterer import EventFilterer
from .BaseEvent import BaseEvent


class FiltererSendPacket(EventFilterer):
	"""
	Since: 1.9.1 
	"""
	type: str

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def canFilter(self, event: str) -> bool:
		pass

	@overload
	def test(self, event: BaseEvent) -> bool:
		pass

	@overload
	def setType(self, type: str) -> "FiltererSendPacket":
		pass

	pass





from typing import overload
from .IChunkSection import IChunkSection


class MixinChunkSelection(IChunkSection):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getNonEmptyBlockCount(self) -> float:
		pass

	@overload
	def jsmacros_getRandomTickableBlockCount(self) -> float:
		pass

	@overload
	def jsmacros_getNonEmptyFluidCount(self) -> float:
		pass

	pass





from typing import overload
from typing import TypeVar

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen


class MixinChatScreen(Screen):

	@overload
	def onSendChatMessage(self, chatText: str, addToHistory: bool, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .AbstractSettingContainer import AbstractSettingContainer
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
from .SettingsOverlay import SettingsOverlay

T = TypeVar("T")
U = TypeVar("U")
net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_OrderedText = TypeVar("net_minecraft_text_OrderedText")
OrderedText = net_minecraft_text_OrderedText

java_util_function_Supplier_T_ = TypeVar("java_util_function_Supplier_T_")
Supplier = java_util_function_Supplier_T_

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class AbstractMapSettingContainer(Generic[T, U], AbstractSettingContainer):
	setting: SettingsOverlay_SettingField
	settingName: OrderedText
	map: Mapping[str, U]
	topScroll: int
	totalHeight: int
	defaultValue: Supplier

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: SettingsOverlay, group: List[str]) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def onScrollbar(self, pages: float) -> None:
		pass

	@overload
	def newField(self, key: str) -> None:
		pass

	@overload
	def addField(self, key: str, value: T) -> None:
		pass

	@overload
	def removeField(self, key: str) -> None:
		pass

	@overload
	def changeValue(self, key: str, newValue: T) -> None:
		pass

	@overload
	def changeKey(self, key: str, newKey: str) -> None:
		pass

	@overload
	def addSetting(self, setting: SettingsOverlay_SettingField) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .FileMapSetting import FileMapSetting

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class FileMapSetting_FileEntry(AbstractMapSettingContainer_MapSettingEntry):

	@overload
	def __init__(self, x: int, y: int, width: int, textRenderer: TextRenderer, parent: FileMapSetting, key: str, value: str) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Button import Button

java_util_function_Consumer_java_lang_String_ = TypeVar("java_util_function_Consumer_java_lang_String_")
Consumer = java_util_function_Consumer_java_lang_String_

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class TextInput(Button):
	onChange: Consumer
	mask: str
	content: str
	selStartIndex: int
	selEndIndex: int

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, color: int, borderColor: int, highlightColor: int, textColor: int, message: str, onClick: Consumer, onChange: Consumer) -> None:
		pass

	@overload
	def setMessage(self, message: str) -> None:
		pass

	@overload
	def updateSelStart(self, startIndex: int) -> None:
		pass

	@overload
	def updateSelEnd(self, endIndex: int) -> None:
		pass

	@overload
	def mouseClicked(self, mouseX: float, mouseY: float, button: int) -> bool:
		pass

	@overload
	def mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> bool:
		pass

	@overload
	def swapStartEnd(self) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def charTyped(self, chr: str, keyCode: int) -> bool:
		pass

	@overload
	def clicked(self, mouseX: float, mouseY: float) -> bool:
		pass

	@overload
	def setSelected(self, sel: bool) -> None:
		pass

	pass





from typing import overload
from typing import List
from .Inventory import Inventory


class LoomInventory(Inventory):
	"""
	Since: 1.5.1 
	"""

	@overload
	def selectPatternName(self, name: str) -> bool:
		"""
		Since: 1.5.1 

		Args:
			name: 

		Returns:
			success 
		"""
		pass

	@overload
	def listAvailablePatterns(self) -> List[str]:
		"""
		Since: 1.7.0 

		Returns:
			available pattern ids 
		"""
		pass

	@overload
	def selectPatternId(self, id: str) -> bool:
		"""
		Since: 1.5.1 

		Args:
			id: 

		Returns:
			success 
		"""
		pass

	@overload
	def selectPattern(self, index: int) -> bool:
		"""
		Since: 1.5.1 

		Args:
			index: 

		Returns:
			success 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent
from .FileChooser_fileObj import FileChooser_fileObj

java_util_function_Consumer_java_io_File_ = TypeVar("java_util_function_Consumer_java_io_File_")
Consumer = java_util_function_Consumer_java_io_File_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

java_io_File = TypeVar("java_io_File")
File = java_io_File

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class FileChooser(OverlayContainer):
	root: File

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, directory: File, selected: File, parent: IOverlayParent, setFile: Consumer, editFile: Consumer) -> None:
		pass

	@overload
	def setDir(self, dir: File) -> None:
		pass

	@overload
	def selectFile(self, f: File) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addFile(self, f: File) -> None:
		pass

	@overload
	def addFile(self, f: File, btnText: str) -> None:
		pass

	@overload
	def updateFilePos(self) -> None:
		pass

	@overload
	def confirmDelete(self, f: FileChooser_fileObj) -> None:
		pass

	@overload
	def delete(self, f: FileChooser_fileObj) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set
from .Core import Core
from .Extension import Extension

java_io_File = TypeVar("java_io_File")
File = java_io_File


class ExtensionLoader:

	@overload
	def __init__(self, core: Core) -> None:
		pass

	@overload
	def isExtensionLoaded(self, name: str) -> bool:
		pass

	@overload
	def notLoaded(self) -> bool:
		pass

	@overload
	def getHighestPriorityExtension(self) -> Extension:
		pass

	@overload
	def getAllExtensions(self) -> Set[Extension]:
		pass

	@overload
	def getExtensionForFile(self, file: File) -> Extension:
		pass

	@overload
	def getExtensionForName(self, lang: str) -> Extension:
		pass

	@overload
	def loadExtensions(self) -> None:
		pass

	@overload
	def isGuestObject(self, obj: object) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .StateHelper import StateHelper
from .BlockPosHelper import BlockPosHelper
from .Pos3D import Pos3D
from .BlockStateHelper import BlockStateHelper

net_minecraft_fluid_FluidState = TypeVar("net_minecraft_fluid_FluidState")
FluidState = net_minecraft_fluid_FluidState


class FluidStateHelper(StateHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FluidState) -> None:
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the fluid's id. 
		"""
		pass

	@overload
	def isStill(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fluid is still, 'false' otherwise. 
		"""
		pass

	@overload
	def isEmpty(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fluid is empty (the default fluid state for non fluid blocks), 'false' otherwise. 
		"""
		pass

	@overload
	def getHeight(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the height of this state. 
		"""
		pass

	@overload
	def getLevel(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the level of this state. 
		"""
		pass

	@overload
	def hasRandomTicks(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the fluid has some random tick logic (only used by lava to do the
fire spread), 'false' otherwise. 
		"""
		pass

	@overload
	def getVelocity(self, pos: BlockPosHelper) -> Pos3D:
		"""
		Since: 1.8.4 

		Args:
			pos: the position in the world 

		Returns:
			the velocity that will be applied to entities at the given position. 
		"""
		pass

	@overload
	def getBlockState(self) -> BlockStateHelper:
		"""
		Since: 1.8.4 

		Returns:
			the block state of this fluid. 
		"""
		pass

	@overload
	def getBlastResistance(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the blast resistance of this fluid. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Consumer_java_lang_Thread_ = TypeVar("java_util_function_Consumer_java_lang_Thread_")
Consumer = java_util_function_Consumer_java_lang_Thread_

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

java_lang_Thread = TypeVar("java_lang_Thread")
Thread = java_lang_Thread


class JsMacrosThreadPool:
	maxFreeThreads: int

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def __init__(self, maxFreeThreads: int) -> None:
		pass

	@overload
	def runTask(self, task: Runnable) -> Thread:
		pass

	@overload
	def runTask(self, task: Runnable, beforeRunTask: Consumer) -> Thread:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseScreen import BaseScreen
from .Core import Core
from .ModLoader import ModLoader

net_minecraft_client_option_KeyBinding = TypeVar("net_minecraft_client_option_KeyBinding")
KeyBinding = net_minecraft_client_option_KeyBinding

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen

net_minecraft_client_MinecraftClient = TypeVar("net_minecraft_client_MinecraftClient")
MinecraftClient = net_minecraft_client_MinecraftClient

net_minecraft_client_util_InputUtil_Key = TypeVar("net_minecraft_client_util_InputUtil_Key")
InputUtil_Key = net_minecraft_client_util_InputUtil_Key

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

org_slf4j_Logger = TypeVar("org_slf4j_Logger")
Logger = org_slf4j_Logger


class JsMacros:
	MOD_ID: str
	LOGGER: Logger
	keyBinding: KeyBinding
	prevScreen: BaseScreen
	core: Core

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onInitialize(self) -> None:
		pass

	@overload
	def onInitializeClient(self) -> None:
		pass

	@overload
	def getKeyText(self, translationKey: str) -> Text:
		pass

	@overload
	def getScreenName(self, s: Screen) -> str:
		pass

	@overload
	def getLocalizedName(self, keyCode: InputUtil_Key) -> str:
		pass

	@overload
	def getMinecraft(self) -> MinecraftClient:
		pass

	@overload
	def range(self, end: int) -> List[int]:
		pass

	@overload
	def range(self, start: int, end: int) -> List[int]:
		pass

	@overload
	def range(self, start: int, end: int, iter: int) -> List[int]:
		pass

	@overload
	def getModLoader(self) -> ModLoader:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .AdvancementProgressHelper import AdvancementProgressHelper

net_minecraft_advancement_PlacedAdvancement = TypeVar("net_minecraft_advancement_PlacedAdvancement")
PlacedAdvancement = net_minecraft_advancement_PlacedAdvancement


class AdvancementHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PlacedAdvancement) -> None:
		pass

	@overload
	def getParent(self) -> "AdvancementHelper":
		"""
		Since: 1.8.4 

		Returns:
			the parent advancement or 'null' if there is none. 
		"""
		pass

	@overload
	def getChildren(self) -> List["AdvancementHelper"]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all child advancements. 
		"""
		pass

	@overload
	def getRequirements(self) -> List[List[str]]:
		"""
		Since: 1.8.4 

		Returns:
			the requirements of this advancement. 
		"""
		pass

	@overload
	def getRequirementCount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of requirements. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of this advancement. 
		"""
		pass

	@overload
	def getExperience(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the experience awarded by this advancement. 
		"""
		pass

	@overload
	def getLoot(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			the loot table ids for this advancement's rewards. 
		"""
		pass

	@overload
	def getRecipes(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			the recipes unlocked through this advancement. 
		"""
		pass

	@overload
	def getProgress(self) -> AdvancementProgressHelper:
		"""
		Since: 1.8.4 

		Returns:
			the progress. 
		"""
		pass

	@overload
	def toJson(self) -> str:
		"""
		Since: 1.9.0 

		Returns:
			the json string of this advancement. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .EntityHelper import EntityHelper

net_minecraft_entity_damage_DamageSource = TypeVar("net_minecraft_entity_damage_DamageSource")
DamageSource = net_minecraft_entity_damage_DamageSource


class EventDamage(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	attacker: EntityHelper
	source: str
	health: float
	change: float

	@overload
	def __init__(self, source: DamageSource, health: float, change: float) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .BaseEvent import BaseEvent

R = TypeVar("R")
T = TypeVar("T")
U = TypeVar("U")

class EventWrappedScript(Generic[T, U, R], BaseEvent):
	"""
	Since: 1.7.0 
	"""
	arg1: T
	arg2: U
	result: R

	@overload
	def __init__(self, arg1: T, arg2: U) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def setReturnBoolean(self, b: bool) -> None:
		pass

	@overload
	def setReturnInt(self, i: int) -> None:
		pass

	@overload
	def setReturnDouble(self, d: float) -> None:
		pass

	@overload
	def setReturnString(self, s: str) -> None:
		pass

	@overload
	def setReturnObject(self, o: object) -> None:
		pass

	pass





from typing import overload
from typing import List
from .CommandBuilder import CommandBuilder
from .CommandNodeHelper import CommandNodeHelper
from .MethodWrapper import MethodWrapper


class CommandManager:
	"""
	Since: 1.7.0 
	"""
	instance: "CommandManager"

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getValidCommands(self) -> List[str]:
		"""
		Since: 1.7.0 

		Returns:
			list of commands 
		"""
		pass

	@overload
	def createCommandBuilder(self, name: str) -> CommandBuilder:
		"""
		Since: 1.7.0 

		Args:
			name: 
		"""
		pass

	@overload
	def unregisterCommand(self, command: str) -> CommandNodeHelper:
		"""
		Since: 1.7.0 

		Args:
			command: 
		"""
		pass

	@overload
	def reRegisterCommand(self, node: CommandNodeHelper) -> None:
		"""warning: this method is hacky\n
		Since: 1.7.0 

		Args:
			node: 
		"""
		pass

	@overload
	def getArgumentAutocompleteOptions(self, commandPart: str, callback: MethodWrapper) -> None:
		"""
		Since: 1.8.2 

		Args:
			commandPart: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .ZombieEntityHelper import ZombieEntityHelper

net_minecraft_entity_mob_DrownedEntity = TypeVar("net_minecraft_entity_mob_DrownedEntity")
DrownedEntity = net_minecraft_entity_mob_DrownedEntity


class DrownedEntityHelper(ZombieEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: DrownedEntity) -> None:
		pass

	@overload
	def hasTrident(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this drowned is holding a trident, 'false' otherwise. 
		"""
		pass

	@overload
	def hasNautilusShell(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this drowned is holding a nautilus shell, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .FormattingHelper import FormattingHelper
from .TextHelper import TextHelper

net_minecraft_entity_boss_BossBar = TypeVar("net_minecraft_entity_boss_BossBar")
BossBar = net_minecraft_entity_boss_BossBar


class BossBarHelper(BaseHelper):
	"""
	Since: 1.2.1 
	"""

	@overload
	def __init__(self, b: BossBar) -> None:
		pass

	@overload
	def getUUID(self) -> str:
		"""
		Since: 1.2.1 

		Returns:
			boss bar uuid. 
		"""
		pass

	@overload
	def getPercent(self) -> float:
		"""
		Since: 1.2.1 

		Returns:
			percent of boss bar remaining. 
		"""
		pass

	@overload
	def getColor(self) -> str:
		"""
		Since: 1.2.1 

		Returns:
			boss bar color. 
		"""
		pass

	@overload
	def getStyle(self) -> str:
		"""
		Since: 1.2.1 

		Returns:
			boss bar notch style. 
		"""
		pass

	@overload
	def getColorValue(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of this boss bar. 
		"""
		pass

	@overload
	def getColorFormat(self) -> FormattingHelper:
		"""
		Since: 1.8.4 

		Returns:
			the format of the boss bar's color. 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""
		Since: 1.2.1 

		Returns:
			name of boss bar 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper

net_minecraft_client_network_ServerInfo = TypeVar("net_minecraft_client_network_ServerInfo")
ServerInfo = net_minecraft_client_network_ServerInfo


class ServerInfoHelper(BaseHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: ServerInfo) -> None:
		pass

	@overload
	def getName(self) -> str:
		pass

	@overload
	def getAddress(self) -> str:
		pass

	@overload
	def getPlayerCountLabel(self) -> TextHelper:
		pass

	@overload
	def getLabel(self) -> TextHelper:
		pass

	@overload
	def getPing(self) -> float:
		pass

	@overload
	def getProtocolVersion(self) -> int:
		pass

	@overload
	def getVersion(self) -> TextHelper:
		pass

	@overload
	def getPlayerListSummary(self) -> List[TextHelper]:
		pass

	@overload
	def resourcePackPolicy(self) -> str:
		pass

	@overload
	def getIcon(self) -> List[float]:
		pass

	@overload
	def isOnline(self) -> bool:
		pass

	@overload
	def isLocal(self) -> bool:
		pass

	@overload
	def getNbt(self) -> NBTElementHelper_NBTCompoundHelper:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .FormattingHelper import FormattingHelper

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

net_minecraft_text_Style = TypeVar("net_minecraft_text_Style")
Style = net_minecraft_text_Style


class StyleHelper(BaseHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: Style) -> None:
		pass

	@overload
	def hasColor(self) -> bool:
		pass

	@overload
	def getColor(self) -> int:
		"""

		Returns:
			the color index of this style or '-1' if no color is set. 
		"""
		pass

	@overload
	def getFormatting(self) -> FormattingHelper:
		"""
		Since: 1.8.4 

		Returns:
			the formatting of this style, or 'null' if no formatting was found. 
		"""
		pass

	@overload
	def getColorIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color index of this style or '-1' if no color is set. 
		"""
		pass

	@overload
	def getColorValue(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color value of this style or '-1' if it doesn't have one. 
		"""
		pass

	@overload
	def getColorName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the color name of this style or 'null' if it has no color. 
		"""
		pass

	@overload
	def hasCustomColor(self) -> bool:
		pass

	@overload
	def getCustomColor(self) -> int:
		pass

	@overload
	def bold(self) -> bool:
		pass

	@overload
	def italic(self) -> bool:
		pass

	@overload
	def underlined(self) -> bool:
		pass

	@overload
	def strikethrough(self) -> bool:
		pass

	@overload
	def obfuscated(self) -> bool:
		pass

	@overload
	def getClickAction(self) -> str:
		pass

	@overload
	def getClickValue(self) -> str:
		pass

	@overload
	def getCustomClickValue(self) -> Runnable:
		pass

	@overload
	def getHoverAction(self) -> str:
		pass

	@overload
	def getHoverValue(self) -> object:
		pass

	@overload
	def getInsertion(self) -> str:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IDraw2D import IDraw2D
from .Registrable import Registrable
from .MethodWrapper import MethodWrapper
from .Text import Text
from .Rect import Rect
from .Line import Line
from .Item import Item
from .Image import Image
from .Draw2DElement import Draw2DElement
from .RenderElement import RenderElement
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper

T = TypeVar("T")
java_util_function_IntSupplier = TypeVar("java_util_function_IntSupplier")
IntSupplier = java_util_function_IntSupplier

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class Draw2D(IDraw2D, Registrable):
	"""
	Since: 1.0.5 
	"""
	widthSupplier: IntSupplier
	heightSupplier: IntSupplier
	zIndex: int
	visible: bool
	onInit: MethodWrapper
	catchInit: MethodWrapper

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getTexts(self) -> List[Text]:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getRects(self) -> List[Rect]:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getLines(self) -> List[Line]:
		pass

	@overload
	def getItems(self) -> List[Item]:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getImages(self) -> List[Image]:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def getDraw2Ds(self) -> List[Draw2DElement]:
		pass

	@overload
	def getElements(self) -> List[RenderElement]:
		pass

	@overload
	def removeElement(self, e: RenderElement) -> "Draw2D":
		pass

	@overload
	def reAddElement(self, e: T) -> T:
		pass

	@overload
	def setVisible(self, visible: bool) -> "Draw2D":
		"""
		Since: 1.8.4 

		Args:
			visible: whether to render this element. 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isVisible(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this draw2d is visible, 'false' otherwise. 
		"""
		pass

	@overload
	def addDraw2D(self, draw2D: "Draw2D", x: int, y: int, width: int, height: int) -> Draw2DElement:
		pass

	@overload
	def addDraw2D(self, draw2D: "Draw2D", x: int, y: int, width: int, height: int, zIndex: int) -> Draw2DElement:
		pass

	@overload
	def removeDraw2D(self, draw2D: Draw2DElement) -> "Draw2D":
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool) -> Text:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> Text:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def removeText(self, t: Text) -> "Draw2D":
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> Image:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.4.0 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def removeImage(self, i: Image) -> "Draw2D":
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> Rect:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> Rect:
		"""
		Since: 1.1.8 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> Rect:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> Rect:
		pass

	@overload
	def removeRect(self, r: Rect) -> "Draw2D":
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, width: float) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int, width: float) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, width: float, rotation: float) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int, width: float, rotation: float) -> Line:
		pass

	@overload
	def removeLine(self, l: Line) -> "Draw2D":
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> Item:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, Item: ItemStackHelper) -> Item:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, Item: ItemStackHelper, overlay: bool) -> Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> Item:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> Item:
		pass

	@overload
	def removeItem(self, i: Item) -> "Draw2D":
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext) -> None:
		pass

	@overload
	def getElementsByZIndex(self) -> iter:
		pass

	@overload
	def setOnInit(self, onInit: MethodWrapper) -> "Draw2D":
		"""init function, called when window is resized or screen/draw2d is registered.
clears all previous elements when called.\n
		Since: 1.2.7 

		Args:
			onInit: calls your method as a Consumer Draw2D 
		"""
		pass

	@overload
	def setOnFailInit(self, catchInit: MethodWrapper) -> "Draw2D":
		"""
		Since: 1.2.7 

		Args:
			catchInit: calls your method as a Consumer String 
		"""
		pass

	@overload
	def register(self) -> "Draw2D":
		"""register so the overlay actually renders\n
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def unregister(self) -> "Draw2D":
		"""unregister so the overlay stops rendering\n
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .Registrable import Registrable
from .Box import Box
from .Line3D import Line3D
from .TraceLine import TraceLine
from .EntityTraceLine import EntityTraceLine
from .Surface import Surface
from .RenderElement3D import RenderElement3D
from .Pos3D import Pos3D
from .EntityHelper import EntityHelper
from .Box_Builder import Box_Builder
from .BlockPosHelper import BlockPosHelper
from .Line3D_Builder import Line3D_Builder
from .TraceLine_Builder import TraceLine_Builder
from .EntityTraceLine_Builder import EntityTraceLine_Builder
from .Surface_Builder import Surface_Builder

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class Draw3D(Registrable):
	"""Draw2D is cool\n
	Since: 1.0.6 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getBoxes(self) -> List[Box]:
		"""
		Since: 1.0.6 
		"""
		pass

	@overload
	def getLines(self) -> List[Line3D]:
		"""
		Since: 1.0.6 
		"""
		pass

	@overload
	def getTraceLines(self) -> List[TraceLine]:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def getEntityTraceLines(self) -> List[EntityTraceLine]:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def getDraw2Ds(self) -> List[Surface]:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def clear(self) -> None:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def reAddElement(self, element: RenderElement3D) -> None:
		"""
		Since: 1.8.4 

		Args:
			element: 
		"""
		pass

	@overload
	def addBox(self, box: Box) -> None:
		"""
		Since: 1.8.4 

		Args:
			box: 
		"""
		pass

	@overload
	def addLine(self, line: Line3D) -> None:
		"""
		Since: 1.8.4 

		Args:
			line: 
		"""
		pass

	@overload
	def addTraceLine(self, line: TraceLine) -> None:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addSurface(self, surface: Surface) -> None:
		"""
		Since: 1.8.4 

		Args:
			surface: 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool) -> Box:
		"""
		Since: 1.0.6 

		Args:
			fillColor: 
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			fill: 

		Returns:
			The Box you added. 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool, cull: bool) -> Box:
		"""
		Since: 1.3.1 

		Args:
			fillColor: 
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			fill: 
			cull: 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, fillColor: int, fillAlpha: int, fill: bool) -> Box:
		"""
		Since: 1.1.8 

		Args:
			fillColor: 
			color: 
			z1: 
			alpha: 
			y1: 
			z2: 
			x1: 
			y2: 
			fillAlpha: 
			x2: 
			fill: 

		Returns:
			the Box you added. 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, fillColor: int, fillAlpha: int, fill: bool, cull: bool) -> Box:
		pass

	@overload
	def removeBox(self, b: Box) -> "Draw3D":
		"""
		Since: 1.0.6 

		Args:
			b: 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int) -> Line3D:
		"""
		Since: 1.0.6 

		Args:
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 

		Returns:
			the Line3D you added. 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, cull: bool) -> Line3D:
		"""
		Since: 1.3.1 

		Args:
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			cull: 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int) -> Line3D:
		"""
		Since: 1.1.8 

		Args:
			color: 
			z1: 
			alpha: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 

		Returns:
			the Line3D you added. 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, cull: bool) -> Line3D:
		"""
		Since: 1.3.1 

		Args:
			color: 
			z1: 
			alpha: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			cull: 
		"""
		pass

	@overload
	def removeLine(self, l: Line3D) -> "Draw3D":
		"""
		Since: 1.0.6 

		Args:
			l: 
		"""
		pass

	@overload
	def addTraceLine(self, x: float, y: float, z: float, color: int) -> TraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addTraceLine(self, x: float, y: float, z: float, color: int, alpha: int) -> TraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addTraceLine(self, pos: Pos3D, color: int) -> TraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addTraceLine(self, pos: Pos3D, color: int, alpha: int) -> TraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addEntityTraceLine(self, entity: EntityHelper, color: int) -> EntityTraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addEntityTraceLine(self, entity: EntityHelper, color: int, alpha: int) -> EntityTraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addEntityTraceLine(self, entity: EntityHelper, color: int, alpha: int, yOffset: float) -> EntityTraceLine:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def removeTraceLine(self, traceLine: TraceLine) -> "Draw3D":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addPoint(self, point: Pos3D, radius: float, color: int) -> Box:
		"""Draws a cube( Box ) with a specific radius( 'side length = 2*radius' )\n
		Since: 1.4.0 

		Args:
			color: point color 
			radius: 1/2 of the side length of the cube 
			point: the center point 

		Returns:
			the Box generated, and visualized 
		"""
		pass

	@overload
	def addPoint(self, x: float, y: float, z: float, radius: float, color: int) -> Box:
		"""Draws a cube( Box ) with a specific radius( 'side length = 2*radius' )\n
		Since: 1.4.0 

		Args:
			color: point color 
			x: x value of the center point 
			y: y value of the center point 
			z: z value of the center point 
			radius: 1/2 of the side length of the cube 

		Returns:
			the Box generated, and visualized 
		"""
		pass

	@overload
	def addPoint(self, x: float, y: float, z: float, radius: float, color: int, alpha: int, cull: bool) -> Box:
		"""Draws a cube( Box ) with a specific radius( 'side length = 2*radius' )\n
		Since: 1.4.0 

		Args:
			color: point color 
			alpha: alpha of the point 
			x: x value of the center point 
			y: y value of the center point 
			z: z value of the center point 
			radius: 1/2 of the side length of the cube 
			cull: whether to cull the point or not 

		Returns:
			the Box generated, and visualized 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			x: top left 
			y: 
			z: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, width: float, height: float) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			x: 
			width: 
			y: 
			z: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			y: 
			z: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			width: 
			y: 
			z: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			width: 
			y: 
			z: 
			minSubdivisions: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int, renderBack: bool) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			width: 
			y: 
			z: 
			minSubdivisions: 
			renderBack: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int, renderBack: bool, cull: bool) -> Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: top left 
			xRot: 
			width: 
			y: 
			z: 
			minSubdivisions: 
			renderBack: 
			height: 
		"""
		pass

	@overload
	def removeDraw2D(self, surface: Surface) -> None:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def boxBuilder(self) -> Box_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a new Box_Builder instance. 
		"""
		pass

	@overload
	def boxBuilder(self, pos: BlockPosHelper) -> Box_Builder:
		"""
		Since: 1.8.4 

		Args:
			pos: the block position of the box 

		Returns:
			a new Box_Builder instance. 
		"""
		pass

	@overload
	def boxBuilder(self, x: int, y: int, z: int) -> Box_Builder:
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate of the box 
			y: the y coordinate of the box 
			z: the z coordinate of the box 

		Returns:
			a new Box_Builder instance. 
		"""
		pass

	@overload
	def lineBuilder(self) -> Line3D_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a new Line3D_Builder instance. 
		"""
		pass

	@overload
	def traceLineBuilder(self) -> TraceLine_Builder:
		"""
		Since: 1.9.0 

		Returns:
			a new TraceLine_Builder instance. 
		"""
		pass

	@overload
	def entityTraceLineBuilder(self) -> EntityTraceLine_Builder:
		"""
		Since: 1.9.0 

		Returns:
			a new EntityTraceLine_Builder instance. 
		"""
		pass

	@overload
	def surfaceBuilder(self) -> Surface_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a new Surface_Builder instance. 
		"""
		pass

	@overload
	def register(self) -> "Draw3D":
		"""register so it actually shows up\n
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def unregister(self) -> "Draw3D":
		"""
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def render(self, drawContext: DrawContext, tickDelta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_AxolotlEntity = TypeVar("net_minecraft_entity_passive_AxolotlEntity")
AxolotlEntity = net_minecraft_entity_passive_AxolotlEntity


class AxolotlEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: AxolotlEntity) -> None:
		pass

	@overload
	def getVariantId(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the id of this axolotl's variant. 
		"""
		pass

	@overload
	def getVariantName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this axolotl's variant. 
		"""
		pass

	@overload
	def isPlayingDead(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the axolotl is playing dead, 'false' otherwise. 
		"""
		pass

	@overload
	def isFromBucket(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the axolotl came from a bucket, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from .BaseEventRegistry import BaseEventRegistry
from .Core import Core
from .ScriptTrigger import ScriptTrigger


class EventRegistry(BaseEventRegistry):

	@overload
	def __init__(self, runner: Core) -> None:
		pass

	@overload
	def addScriptTrigger(self, rawmacro: ScriptTrigger) -> None:
		pass

	@overload
	def removeScriptTrigger(self, rawmacro: ScriptTrigger) -> bool:
		pass

	@overload
	def getScriptTriggers(self) -> List[ScriptTrigger]:
		pass

	pass





from typing import overload
from typing import List


class ServiceManager_ServiceStatus:
	ENABLED: "ServiceManager_ServiceStatus"
	DISABLED: "ServiceManager_ServiceStatus"
	RUNNING: "ServiceManager_ServiceStatus"
	STOPPED: "ServiceManager_ServiceStatus"
	UNKNOWN: "ServiceManager_ServiceStatus"

	@overload
	def values(self) -> List["ServiceManager_ServiceStatus"]:
		pass

	@overload
	def valueOf(self, name: str) -> "ServiceManager_ServiceStatus":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .AnimalEntityHelper import AnimalEntityHelper
from .LivingEntityHelper import LivingEntityHelper

T = TypeVar("T")

class TameableEntityHelper(Generic[T], AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def isTamed(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the entity is tamed, 'false' otherwise. 
		"""
		pass

	@overload
	def isSitting(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the entity is sitting, 'false' otherwise. 
		"""
		pass

	@overload
	def getOwner(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the owner's uuid, or 'null' if the entity is not tamed. 
		"""
		pass

	@overload
	def isOwner(self, owner: LivingEntityHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			owner: the possible owner 

		Returns:
			'true' if the entity is tamed by the given owner, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement import RenderElement
from .Alignable import Alignable
from .Draw2D import Draw2D
from .IDraw2D import IDraw2D

java_util_function_IntSupplier = TypeVar("java_util_function_IntSupplier")
IntSupplier = java_util_function_IntSupplier

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class Draw2DElement(RenderElement, Alignable):
	"""
	Since: 1.8.4 
	"""
	draw2D: Draw2D
	parent: IDraw2D
	x: int
	y: int
	width: IntSupplier
	height: IntSupplier
	scale: float
	rotation: float
	rotateCenter: bool
	zIndex: int

	@overload
	def __init__(self, draw2D: Draw2D, x: int, y: int, width: IntSupplier, height: IntSupplier, zIndex: int, scale: float, rotation: float) -> None:
		pass

	@overload
	def getDraw2D(self) -> Draw2D:
		"""
		Since: 1.8.4 

		Returns:
			the internal draw2D this draw2D element is wrapping. 
		"""
		pass

	@overload
	def setX(self, x: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			x: the x position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of this draw2D. 
		"""
		pass

	@overload
	def setY(self, y: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			y: the y position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of this draw2D. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			x: the x position 
			y: the y position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setWidth(self, width: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			width: the width 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of this draw2D. 
		"""
		pass

	@overload
	def setHeight(self, height: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			height: the height 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of this draw2D. 
		"""
		pass

	@overload
	def setSize(self, width: int, height: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			width: the width 
			height: the height 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setScale(self, scale: float) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			scale: the scale 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of this draw2D. 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation of this draw2D. 
		"""
		pass

	@overload
	def setRotateCenter(self, rotateCenter: bool) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether this draw2D should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this draw2D should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> "Draw2DElement":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the z-index of this draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def setParent(self, parent: IDraw2D) -> "Draw2DElement":
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Draw2DElement":
		pass

	pass





from typing import overload
from typing import TypeVar

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo


class MixinHungerManager:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onSetFoodLevel(self, foodLevel: int, info: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .RecipeInventory import RecipeInventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_AbstractFurnaceScreen__ = TypeVar("net_minecraft_client_gui_screen_ingame_AbstractFurnaceScreen__")
AbstractFurnaceScreen = net_minecraft_client_gui_screen_ingame_AbstractFurnaceScreen__


class FurnaceInventory(RecipeInventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: AbstractFurnaceScreen) -> None:
		pass

	@overload
	def getInput(self, x: int, y: int) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the input, will always be 0 
			y: the y position of the input, will always be 0 

		Returns:
			the currently smelting item. 
		"""
		pass

	@overload
	def getSmeltedItem(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the currently smelting item. 
		"""
		pass

	@overload
	def getFuel(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the fuel item. 
		"""
		pass

	@overload
	def canUseAsFuel(self, stack: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			stack: the item to check 

		Returns:
			'true' if the item is a valid fuel, 'false' otherwise. 
		"""
		pass

	@overload
	def isSmeltable(self, stack: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			stack: the item to check 

		Returns:
			'true' if the item can be smelted, 'false' otherwise. 
		"""
		pass

	@overload
	def getFuelValues(self) -> Mapping[str, int]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all valid fuels and their burn times in ticks. 
		"""
		pass

	@overload
	def getSmeltingProgress(self) -> int:
		"""If the returned value equals FurnaceInventory#getTotalSmeltingTime() then the item is done smelting.\n
		Since: 1.8.4 

		Returns:
			the current Smelting progress in ticks. 
		"""
		pass

	@overload
	def getTotalSmeltingTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the total smelting time of a single input item in ticks. 
		"""
		pass

	@overload
	def getRemainingSmeltingTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the remaining time of the smelting progress in ticks. 
		"""
		pass

	@overload
	def getRemainingFuelTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the remaining fuel time in ticks. 
		"""
		pass

	@overload
	def getTotalFuelTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the total fuel time of the current fuel item in ticks. 
		"""
		pass

	@overload
	def isBurning(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the furnace is currently smelting an item, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Set
from .Extension_ExtMatch import Extension_ExtMatch
from .Core import Core
from .BaseLanguage import BaseLanguage
from .BaseWrappedException import BaseWrappedException

java_lang_Throwable = TypeVar("java_lang_Throwable")
Throwable = java_lang_Throwable

java_io_File = TypeVar("java_io_File")
File = java_io_File


class Extension:

	@overload
	def minCoreVersion(self) -> str:
		"""
		Since: 1.9.0 

		Returns:
			the *minimum* version of the jsMacros core that this extension is compatible with. 
		"""
		pass

	@overload
	def maxCoreVersion(self) -> str:
		"""
		Since: 1.9.0 

		Returns:
			the *maximum* version of the jsMacros core that this extension is compatible with. 
		"""
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def getPriority(self) -> int:
		pass

	@overload
	def getLanguageImplName(self) -> str:
		pass

	@overload
	def extensionMatch(self, file: File) -> Extension_ExtMatch:
		pass

	@overload
	def defaultFileExtension(self) -> str:
		pass

	@overload
	def getLanguage(self, runner: Core) -> BaseLanguage:
		"""

		Returns:
			a single static instance of the language definition 
		"""
		pass

	@overload
	def getLibraries(self) -> Set[Class]:
		pass

	@overload
	def getDependencies(self) -> Set[URL]:
		pass

	@overload
	def getDependenciesInternal(self, clazz: Class, fname: str) -> Set[URL]:
		pass

	@overload
	def wrapException(self, t: Throwable) -> BaseWrappedException:
		pass

	@overload
	def getTranslations(self, lang: str) -> Mapping[str, str]:
		pass

	@overload
	def getTranslationsInternal(self, clazz: Class, fname: str) -> Mapping[str, str]:
		pass

	@overload
	def isGuestObject(self, o: object) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Set

net_minecraft_util_Identifier = TypeVar("net_minecraft_util_Identifier")
Identifier = net_minecraft_util_Identifier

net_minecraft_advancement_PlacedAdvancement = TypeVar("net_minecraft_advancement_PlacedAdvancement")
PlacedAdvancement = net_minecraft_advancement_PlacedAdvancement


class MixinAdvancementManager:
	"""
	Since: 1.8.4 
	"""

	@overload
	def getAdvancements(self) -> Mapping[Identifier, PlacedAdvancement]:
		pass

	@overload
	def getDependents(self) -> Set[PlacedAdvancement]:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .VillagerInventory import VillagerInventory
from .ItemStackHelper import ItemStackHelper
from .NBTElementHelper import NBTElementHelper

net_minecraft_village_TradeOffer = TypeVar("net_minecraft_village_TradeOffer")
TradeOffer = net_minecraft_village_TradeOffer


class TradeOfferHelper(BaseHelper):

	@overload
	def __init__(self, base: TradeOffer, index: int, inv: VillagerInventory) -> None:
		pass

	@overload
	def getInput(self) -> List[ItemStackHelper]:
		"""

		Returns:
			list of input items required 
		"""
		pass

	@overload
	def getLeftInput(self) -> ItemStackHelper:
		"""The returned item uses the adjusted price, in form of its stack size and will be empty ItemStackHelper#isEmpty() if the first input doesn't exist.\n
		Since: 1.8.4 

		Returns:
			the first input item. 
		"""
		pass

	@overload
	def getRightInput(self) -> ItemStackHelper:
		"""The returned item uses the adjusted price, in form of its stack size and will be empty ItemStackHelper#isEmpty() if the first input doesn't exist.\n
		Since: 1.8.4 

		Returns:
			the second input item. 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""

		Returns:
			output item that will be received 
		"""
		pass

	@overload
	def getIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the index if this trade in the given villager inventory. 
		"""
		pass

	@overload
	def select(self) -> "TradeOfferHelper":
		"""select trade offer on screen
		"""
		pass

	@overload
	def isAvailable(self) -> bool:
		"""
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper:
		"""

		Returns:
			trade offer as nbt tag 
		"""
		pass

	@overload
	def getUses(self) -> int:
		"""

		Returns:
			current number of uses 
		"""
		pass

	@overload
	def getMaxUses(self) -> int:
		"""

		Returns:
			max uses before it locks 
		"""
		pass

	@overload
	def shouldRewardPlayerExperience(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if after a successful trade xp will be summoned, 'false' otherwise. 
		"""
		pass

	@overload
	def getExperience(self) -> int:
		"""

		Returns:
			experience gained for trade 
		"""
		pass

	@overload
	def getCurrentPriceAdjustment(self) -> int:
		"""

		Returns:
			current price adjustment, negative is discount. 
		"""
		pass

	@overload
	def getOriginalFirstInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the original priced item without any adjustments due to rewards or demand. 
		"""
		pass

	@overload
	def getOriginalPrice(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the original price of the item without any adjustments due to rewards or demand. 
		"""
		pass

	@overload
	def getAdjustedPrice(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the adjusted price of the item. 
		"""
		pass

	@overload
	def getSpecialPrice(self) -> int:
		"""A negative value is a discount and means that the player has a good reputation with the
villager, while a positive value is a premium. Hero of the village will always affect and
reduce this value.\n
		Since: 1.8.4 

		Returns:
			the special price multiplier, which affects the price of the item depending on the
player's reputation with the villager. 
		"""
		pass

	@overload
	def getPriceMultiplier(self) -> float:
		"""A higher price multiplier means that the price of these trades can vary much more than normal
ones. The default value is 0.05 and 0.2 for armor and tools.\n
		Since: 1.8.4 

		Returns:
			the price multiplier, which is only depended on the type of trade. 
		"""
		pass

	@overload
	def getDemandBonus(self) -> int:
		"""The demand bonus is globally applied to all trades of this type for all villagers and
players. It is used to increase the price of trades that are in high demand. The demand is
only calculated and updated on restock. Note that a villager can always restock, even if no
items were traded with him. Updating the demand is done with the following formula:  'demand = demand + 2 * uses - maxUses'   
Thus trading only half of the max uses will not increase the demand.
The demand is also capped at 0, so it can not decrease the price.\n
		Since: 1.8.4 

		Returns:
			the demand bonus for this trade. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .Alignable import Alignable
from .TextHelper import TextHelper

B = TypeVar("B")
B = B

T = TypeVar("T")
U = TypeVar("U")

class AbstractWidgetBuilder(Alignable, Generic[B, T, U]):
	"""
	Since: 1.8.4 
	"""

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the widget. 
		"""
		pass

	@overload
	def width(self, width: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			width: the width of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the widget. 
		"""
		pass

	@overload
	def height(self, height: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			height: the height of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def size(self, width: int, height: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			width: the width of the widget 
			height: the height of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the widget. 
		"""
		pass

	@overload
	def zIndex(self, zIndex: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			zIndex: the z-index of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the widget. 
		"""
		pass

	@overload
	def x(self, x: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the widget. 
		"""
		pass

	@overload
	def y(self, y: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			y: the y position of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, x: int, y: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the widget 
			y: the y position of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMessage(self) -> TextHelper:
		"""
		Since: 1.8.4 

		Returns:
			the message of the widget or an empty text if none is set. 
		"""
		pass

	@overload
	def message(self, message: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			message: the message of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def message(self, message: TextHelper) -> B:
		"""
		Since: 1.8.4 

		Args:
			message: the message of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isActive(self) -> bool:
		"""An inactive widget can not be interacted with and may have a different appearance.\n
		Since: 1.8.4 

		Returns:
			'true' if the widget is active, 'false' otherwise. 
		"""
		pass

	@overload
	def active(self, active: bool) -> B:
		"""An inactive widget can not be interacted with and may have a different appearance.\n
		Since: 1.8.4 

		Args:
			active: whether the widget should be active or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isVisible(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the widget is visible, 'false' otherwise. 
		"""
		pass

	@overload
	def visible(self, visible: bool) -> B:
		"""
		Since: 1.8.4 

		Args:
			visible: whether the widget should be visible or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlpha(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the widget. 
		"""
		pass

	@overload
	def alpha(self, alpha: float) -> B:
		"""
		Since: 1.8.4 

		Args:
			alpha: the alpha value of the widget 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def build(self) -> U:
		"""
		Since: 1.8.4 

		Returns:
			the build widget for the set properties. 
		"""
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> B:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_MinecraftClient = TypeVar("net_minecraft_client_MinecraftClient")
MinecraftClient = net_minecraft_client_MinecraftClient

net_minecraft_client_network_MultiplayerServerListPinger = TypeVar("net_minecraft_client_network_MultiplayerServerListPinger")
MultiplayerServerListPinger = net_minecraft_client_network_MultiplayerServerListPinger

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class TickBasedEvents:
	serverListPinger: MultiplayerServerListPinger

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def areNotEqual(self, a: ItemStack, b: ItemStack) -> bool:
		pass

	@overload
	def areTagsEqualIgnoreDamage(self, a: ItemStack, b: ItemStack) -> bool:
		pass

	@overload
	def areEqualIgnoreDamage(self, a: ItemStack, b: ItemStack) -> bool:
		pass

	@overload
	def onTick(self, mc: MinecraftClient) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .LivingEntityHelper import LivingEntityHelper
from .PlayerAbilitiesHelper import PlayerAbilitiesHelper
from .ItemStackHelper import ItemStackHelper
from .FishingBobberEntityHelper import FishingBobberEntityHelper

T = TypeVar("T")

class PlayerEntityHelper(Generic[T], LivingEntityHelper):
	"""
	"""

	@overload
	def __init__(self, e: T) -> None:
		pass

	@overload
	def getPlayerName(self) -> str:
		"""get player's actual name. (not display name)\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getAbilities(self) -> PlayerAbilitiesHelper:
		"""
		Since: 1.0.3 
		"""
		pass

	@overload
	def getMainHand(self) -> ItemStackHelper:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getOffHand(self) -> ItemStackHelper:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getHeadArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getChestArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getLegArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getFootArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getXP(self) -> int:
		"""
		Since: 1.2.5 [citation needed] 
		"""
		pass

	@overload
	def getXPLevel(self) -> int:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getXPProgress(self) -> float:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getXPToLevelUp(self) -> int:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def isSleeping(self) -> bool:
		"""
		Since: 1.2.5 [citation needed] 
		"""
		pass

	@overload
	def isSleepingLongEnough(self) -> bool:
		"""
		Since: 1.2.5 [citation needed] 

		Returns:
			if the player has slept the minimum amount of time to pass the night. 
		"""
		pass

	@overload
	def getFishingBobber(self) -> FishingBobberEntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the fishing bobber of the player, or 'null' if the player is not fishing. 
		"""
		pass

	@overload
	def getAttackCooldownProgress(self) -> float:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getAttackCooldownProgressPerTick(self) -> float:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getScore(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the player's score. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .LivingEntityHelper import LivingEntityHelper

T = TypeVar("T")

class MobEntityHelper(Generic[T], LivingEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def isAttacking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the entity is currently attacking something, 'false' otherwise. 
		"""
		pass

	@overload
	def isAiDisabled(self) -> bool:
		"""Mobs which have there AI disabled don't move, attack, or interact with the world by
themselves.\n
		Since: 1.8.4 

		Returns:
			'true' if the entity's AI is disabled, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

C = TypeVar("C")
C = C

java_util_function_Predicate_T_ = TypeVar("java_util_function_Predicate_T_")
Predicate = java_util_function_Predicate_T_

java_util_Comparator_T_ = TypeVar("java_util_Comparator_T_")
Comparator = java_util_Comparator_T_

java_lang_Thread = TypeVar("java_lang_Thread")
Thread = java_lang_Thread

java_util_function_Function_ super R, extends V_ = TypeVar("java_util_function_Function_ super R, extends V_")
Function = java_util_function_Function_ super R, extends V_

R = TypeVar("R")
T = TypeVar("T")
java_util_function_Consumer_T_ = TypeVar("java_util_function_Consumer_T_")
Consumer = java_util_function_Consumer_T_

U = TypeVar("U")
java_util_function_BiFunction_T,U,R_ = TypeVar("java_util_function_BiFunction_T,U,R_")
BiFunction = java_util_function_BiFunction_T,U,R_

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

java_util_function_Supplier_R_ = TypeVar("java_util_function_Supplier_R_")
Supplier = java_util_function_Supplier_R_

java_util_function_BiConsumer_T,U_ = TypeVar("java_util_function_BiConsumer_T,U_")
BiConsumer = java_util_function_BiConsumer_T,U_

java_util_function_BiPredicate_T,U_ = TypeVar("java_util_function_BiPredicate_T,U_")
BiPredicate = java_util_function_BiPredicate_T,U_


class MethodWrapper(Consumer, BiConsumer, Function, BiFunction, Predicate, BiPredicate, Runnable, Supplier, Comparator, Generic[T, U, R, C]):
	"""Wraps most of the important functional interfaces.
	"""

	@overload
	def __init__(self, containingContext: C) -> None:
		pass

	@overload
	def getCtx(self) -> C:
		pass

	@overload
	def accept(self, t: T) -> None:
		pass

	@overload
	def accept(self, t: T, u: U) -> None:
		pass

	@overload
	def apply(self, t: T) -> R:
		pass

	@overload
	def apply(self, t: T, u: U) -> R:
		pass

	@overload
	def test(self, t: T) -> bool:
		pass

	@overload
	def test(self, t: T, u: U) -> bool:
		pass

	@overload
	def preventSameScriptJoin(self) -> bool:
		"""override to return true if the method can't join to the context it was wrapped/created in, ie for languages that don't allow multithreading.
		"""
		pass

	@overload
	def overrideThread(self) -> Thread:
		"""make return something to override the thread set in FJsMacros#on(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) (hi jep)
		"""
		pass

	@overload
	def andThen(self, after: Function) -> "MethodWrapper":
		"""Makes Function and BiFunction work together.
Extended so it's called on every type not just those 2.

		Args:
			after: put a MethodWrapper here when using in scripts. 
		"""
		pass

	@overload
	def negate(self) -> "MethodWrapper":
		"""Makes Predicate and BiPredicate work together
		"""
		pass

	pass





from typing import overload


class TickSync:
	"""
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def waitTick(self) -> None:
		pass

	@overload
	def waitTicks(self, ticks: int) -> None:
		pass

	@overload
	def tick(self) -> None:
		pass

	pass





from typing import overload
from .Pos2D import Pos2D
from .Vec3D import Vec3D


class Vec2D:
	"""
	Since: 1.2.6 [citation needed] 
	"""
	x1: float
	y1: float
	x2: float
	y2: float

	@overload
	def __init__(self, x1: float, y1: float, x2: float, y2: float) -> None:
		pass

	@overload
	def __init__(self, start: Pos2D, end: Pos2D) -> None:
		pass

	@overload
	def getX1(self) -> float:
		pass

	@overload
	def getY1(self) -> float:
		pass

	@overload
	def getX2(self) -> float:
		pass

	@overload
	def getY2(self) -> float:
		pass

	@overload
	def getDeltaX(self) -> float:
		pass

	@overload
	def getDeltaY(self) -> float:
		pass

	@overload
	def getStart(self) -> Pos2D:
		pass

	@overload
	def getEnd(self) -> Pos2D:
		pass

	@overload
	def getMagnitude(self) -> float:
		pass

	@overload
	def getMagnitudeSq(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			magnitude squared 
		"""
		pass

	@overload
	def add(self, vec: "Vec2D") -> "Vec2D":
		pass

	@overload
	def add(self, x1: float, y1: float, x2: float, y2: float) -> "Vec2D":
		"""
		Since: 1.6.3 

		Args:
			y1: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def multiply(self, vec: "Vec2D") -> "Vec2D":
		pass

	@overload
	def multiply(self, x1: float, y1: float, x2: float, y2: float) -> "Vec2D":
		"""
		Since: 1.6.3 

		Args:
			y1: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Vec2D":
		"""
		Since: 1.6.3 

		Args:
			scale: 
		"""
		pass

	@overload
	def dotProduct(self, vec: "Vec2D") -> float:
		pass

	@overload
	def reverse(self) -> "Vec2D":
		pass

	@overload
	def normalize(self) -> "Vec2D":
		"""
		Since: 1.6.5 

		Returns:
			a new Vec2D with the same direction but a magnitude of 1 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def to3D(self) -> Vec3D:
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareTo(self, other: "Vec2D") -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseLibrary import BaseLibrary
from .PlayerEntityHelper import PlayerEntityHelper
from .PlayerListEntryHelper import PlayerListEntryHelper
from .BlockDataHelper import BlockDataHelper
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .ChunkHelper import ChunkHelper
from .WorldScannerBuilder import WorldScannerBuilder
from .MethodWrapper import MethodWrapper
from .WorldScanner import WorldScanner
from .ScoreboardsHelper import ScoreboardsHelper
from .EntityHelper import EntityHelper
from .BossBarHelper import BossBarHelper
from .TextHelper import TextHelper

net_minecraft_client_world_ClientWorld = TypeVar("net_minecraft_client_world_ClientWorld")
ClientWorld = net_minecraft_client_world_ClientWorld


class FWorld(BaseLibrary):
	"""Functions for getting and using world data. 
An instance of this class is passed to scripts as the 'World' variable.
	"""
	serverInstantTPS: float
	server1MAverageTPS: float
	server5MAverageTPS: float
	server15MAverageTPS: float

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def isWorldLoaded(self) -> bool:
		"""returns whether a world is currently loaded\n
		Since: 1.3.0 
		"""
		pass

	@overload
	def getLoadedPlayers(self) -> List[PlayerEntityHelper]:
		"""

		Returns:
			players within render distance. 
		"""
		pass

	@overload
	def getPlayers(self) -> List[PlayerListEntryHelper]:
		"""

		Returns:
			players on the tablist. 
		"""
		pass

	@overload
	def getPlayerEntry(self, name: str) -> PlayerListEntryHelper:
		"""
		Since: 1.8.4 

		Args:
			name: the name of the player to get the entry for 

		Returns:
			player entry for the given player's name or 'null' if not found. 
		"""
		pass

	@overload
	def getBlock(self, x: int, y: int, z: int) -> BlockDataHelper:
		"""

		Args:
			x: 
			y: 
			z: 

		Returns:
			The block at that position. 
		"""
		pass

	@overload
	def getBlock(self, pos: Pos3D) -> BlockDataHelper:
		pass

	@overload
	def getBlock(self, pos: BlockPosHelper) -> BlockDataHelper:
		pass

	@overload
	def getChunk(self, x: int, z: int) -> ChunkHelper:
		"""The x and z position of the chunk can be calculated by the following formula: xChunk =
x >> 4; zChunk = z >> 4;\n
		Since: 1.8.4 

		Args:
			x: the x coordinate of the chunk, not the absolute position 
			z: the z coordinate of the chunk, not the absolute position 

		Returns:
			ChunkHelper for the chunk coordinates ChunkHelper . 
		"""
		pass

	@overload
	def getWorldScanner(self) -> WorldScannerBuilder:
		"""Usage: This will return all blocks that are facing south, don't require a tool to break,
have a hardness of 10 or less and whose name contains either chest or barrel. World.getWorldScanner()
    .withBlockFilter("getHardness").is(" =", 10)
    .andStringBlockFilter().contains("chest", "barrel")
    .withStringStateFilter().contains("facing=south")
    .andStateFilter("isToolRequired").is(false)
    .build()\n
		Since: 1.6.5 

		Returns:
			a builder to create a WorldScanner. 
		"""
		pass

	@overload
	def getWorldScanner(self, blockFilter: MethodWrapper, stateFilter: MethodWrapper) -> WorldScanner:
		"""
		Since: 1.6.5 

		Returns:
			a scanner for the current world. 
		"""
		pass

	@overload
	def findBlocksMatching(self, centerX: int, centerZ: int, id: str, chunkrange: int) -> List[Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			chunkrange: 
			id: 
		"""
		pass

	@overload
	def findBlocksMatching(self, id: str, chunkrange: int) -> List[Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			chunkrange: 
			id: 
		"""
		pass

	@overload
	def findBlocksMatching(self, ids: List[str], chunkrange: int) -> List[Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			chunkrange: 
			ids: 
		"""
		pass

	@overload
	def findBlocksMatching(self, centerX: int, centerZ: int, ids: List[str], chunkrange: int) -> List[Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			centerZ: 
			centerX: 
			chunkrange: 
			ids: 
		"""
		pass

	@overload
	def findBlocksMatching(self, blockFilter: MethodWrapper, stateFilter: MethodWrapper, chunkrange: int) -> List[Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			blockFilter: 
			stateFilter: 
			chunkrange: 
		"""
		pass

	@overload
	def findBlocksMatching(self, chunkX: int, chunkZ: int, blockFilter: MethodWrapper, stateFilter: MethodWrapper, chunkrange: int) -> List[Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			blockFilter: 
			stateFilter: 
			chunkrange: 
			chunkX: 
			chunkZ: 
		"""
		pass

	@overload
	def iterateSphere(self, pos: BlockPosHelper, radius: int, callback: MethodWrapper) -> None:
		"""By default, air blocks are ignored and the callback is only called for real blocks.\n
		Since: 1.8.4 

		Args:
			pos: the center position 
			callback: the callback to call for each block 
			radius: the radius to scan 
		"""
		pass

	@overload
	def iterateSphere(self, pos: BlockPosHelper, radius: int, ignoreAir: bool, callback: MethodWrapper) -> None:
		"""
		Since: 1.8.4 

		Args:
			pos: the center position 
			callback: the callback to call for each block 
			radius: the radius to scan 
			ignoreAir: whether to ignore air blocks 
		"""
		pass

	@overload
	def iterateBox(self, pos1: BlockPosHelper, pos2: BlockPosHelper, callback: MethodWrapper) -> None:
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position 
			callback: the callback to call for each block 
			pos2: the second position 
		"""
		pass

	@overload
	def iterateBox(self, pos1: BlockPosHelper, pos2: BlockPosHelper, ignoreAir: bool, callback: MethodWrapper) -> None:
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position 
			callback: the callback to call for each block 
			pos2: the second position 
			ignoreAir: whether to ignore air blocks 
		"""
		pass

	@overload
	def getScoreboards(self) -> ScoreboardsHelper:
		"""
		Since: 1.2.9 

		Returns:
			a helper for the scoreboards provided to the client. 
		"""
		pass

	@overload
	def getEntities(self) -> List[EntityHelper]:
		"""

		Returns:
			all entities in the render distance. 
		"""
		pass

	@overload
	def getEntities(self, types: List[str]) -> List[EntityHelper]:
		"""
		Since: 1.8.4 

		Args:
			types: the entity types to consider 

		Returns:
			all entities in the render distance, that match the specified entity type. 
		"""
		pass

	@overload
	def getEntities(self, distance: float) -> List[EntityHelper]:
		"""
		Since: 1.8.4 

		Args:
			distance: the maximum distance to search for entities 

		Returns:
			a list of entities within the specified distance to the player. 
		"""
		pass

	@overload
	def getEntities(self, distance: float, types: List[str]) -> List[EntityHelper]:
		"""
		Since: 1.8.4 

		Args:
			types: the entity types to consider 
			distance: the maximum distance to search for entities 

		Returns:
			a list of entities within the specified distance to the player, that match the specified entity type. 
		"""
		pass

	@overload
	def getEntities(self, filter: MethodWrapper) -> List[EntityHelper]:
		"""
		Since: 1.8.4 

		Args:
			filter: the entity filter 

		Returns:
			a list of entities that match the specified filter. 
		"""
		pass

	@overload
	def rayTraceBlock(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, fluid: bool) -> BlockDataHelper:
		"""raytrace between two points returning the first block hit.\n
		Since: 1.6.5 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			fluid: 
		"""
		pass

	@overload
	def rayTraceEntity(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> EntityHelper:
		"""raytrace between two points returning the first entity hit.\n
		Since: 1.8.3 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def getDimension(self) -> str:
		"""note that some server might utilize dimension identifiers for mods to distinguish between worlds.\n
		Since: 1.1.2 

		Returns:
			the current dimension. 
		"""
		pass

	@overload
	def getBiome(self) -> str:
		"""
		Since: 1.1.5 

		Returns:
			the current biome. 
		"""
		pass

	@overload
	def getTime(self) -> float:
		"""ticks processed since world was started.\n
		Since: 1.1.5 

		Returns:
			the current world time. '-1' if world is not loaded. 
		"""
		pass

	@overload
	def getTimeOfDay(self) -> float:
		"""ticks passed since world was started INCLUDING those skipped when nights were cut short with sleeping.\n
		Since: 1.1.5 

		Returns:
			the current world time of day. '-1' if world is not loaded. 
		"""
		pass

	@overload
	def isDay(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if it is daytime, 'false' otherwise. 
		"""
		pass

	@overload
	def isNight(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if it is nighttime, 'false' otherwise. 
		"""
		pass

	@overload
	def isRaining(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if it is raining, 'false' otherwise. 
		"""
		pass

	@overload
	def isThundering(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if it is thundering, 'false' otherwise. 
		"""
		pass

	@overload
	def getWorldIdentifier(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			an identifier for the loaded world that is based on the world's name or server ip and
thus most likely unique enough to identify a specific world, or '"UNKNOWN_NAME"' if no world was found. 
		"""
		pass

	@overload
	def getRespawnPos(self) -> BlockPosHelper:
		"""
		Since: 1.2.6 

		Returns:
			respawn position. 
		"""
		pass

	@overload
	def getDifficulty(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			world difficulty as an Integer . '-1' if world is not loaded. 
		"""
		pass

	@overload
	def getMoonPhase(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			moon phase as an Integer . '-1' if world is not loaded. 
		"""
		pass

	@overload
	def getSkyLight(self, x: int, y: int, z: int) -> int:
		"""
		Since: 1.1.2 

		Args:
			x: 
			y: 
			z: 

		Returns:
			sky light as an Integer . '-1' if world is not loaded. 
		"""
		pass

	@overload
	def getBlockLight(self, x: int, y: int, z: int) -> int:
		"""
		Since: 1.1.2 

		Args:
			x: 
			y: 
			z: 

		Returns:
			block light as an Integer . '-1' if world is not loaded. 
		"""
		pass

	@overload
	def playSoundFile(self, file: str, volume: float) -> Clip:
		"""plays a sound file using javax's sound stuff.\n
		Since: 1.1.7 

		Args:
			volume: 
			file: 
		"""
		pass

	@overload
	def playSound(self, id: str) -> None:
		"""
		Since: 1.1.7 

		Args:
			id: 
		"""
		pass

	@overload
	def playSound(self, id: str, volume: float) -> None:
		"""
		Since: 1.1.7 

		Args:
			volume: 
			id: 
		"""
		pass

	@overload
	def playSound(self, id: str, volume: float, pitch: float) -> None:
		"""
		Since: 1.1.7 

		Args:
			volume: 
			id: 
			pitch: 
		"""
		pass

	@overload
	def playSound(self, id: str, volume: float, pitch: float, x: float, y: float, z: float) -> None:
		"""plays a minecraft sound using the internal system.\n
		Since: 1.1.7 

		Args:
			volume: 
			x: 
			y: 
			z: 
			id: 
			pitch: 
		"""
		pass

	@overload
	def getBossBars(self) -> Mapping[str, BossBarHelper]:
		"""
		Since: 1.2.1 

		Returns:
			a map of boss bars by the boss bar's UUID. 
		"""
		pass

	@overload
	def isChunkLoaded(self, chunkX: int, chunkZ: int) -> bool:
		"""Check whether a chunk is within the render distance and loaded.\n
		Since: 1.2.2 

		Args:
			chunkX: 
			chunkZ: 
		"""
		pass

	@overload
	def getCurrentServerAddress(self) -> str:
		"""
		Since: 1.2.2 

		Returns:
			the current server address as a string ( 'server.address/server.ip:port' ). 
		"""
		pass

	@overload
	def getBiomeAt(self, x: int, z: int) -> str:
		"""
		Since: 1.2.2 [Citation Needed] 

		Args:
			x: 
			z: 

		Returns:
			biome at specified location, only works if the block/chunk is loaded. 
		"""
		pass

	@overload
	def getBiomeAt(self, x: int, y: int, z: int) -> str:
		"""
		Since: 1.8.4 

		Args:
			x: 
			y: 
			z: 

		Returns:
			biome at specified location, only works if the block/chunk is loaded. 
		"""
		pass

	@overload
	def getServerTPS(self) -> str:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps with various timings. 
		"""
		pass

	@overload
	def getTabListHeader(self) -> TextHelper:
		"""
		Since: 1.3.1 

		Returns:
			text helper for the top part of the tab list (above the players) 
		"""
		pass

	@overload
	def getTabListFooter(self) -> TextHelper:
		"""
		Since: 1.3.1 

		Returns:
			text helper for the bottom part of the tab list (below the players) 
		"""
		pass

	@overload
	def spawnParticle(self, id: str, x: float, y: float, z: float, count: int) -> None:
		"""Summons the amount of particles at the desired position.\n
		Since: 1.8.4 

		Args:
			x: the x position to spawn the particle 
			count: the amount of particles to spawn 
			y: the y position to spawn the particle 
			z: the z position to spawn the particle 
			id: the particle id 
		"""
		pass

	@overload
	def spawnParticle(self, id: str, x: float, y: float, z: float, deltaX: float, deltaY: float, deltaZ: float, speed: float, count: int, force: bool) -> None:
		"""Summons the amount of particles at the desired position with some variation of delta and the
given speed.\n
		Since: 1.8.4 

		Args:
			deltaZ: the z variation of the particle 
			deltaX: the x variation of the particle 
			deltaY: the y variation of the particle 
			x: the x position to spawn the particle 
			count: the amount of particles to spawn 
			y: the y position to spawn the particle 
			z: the z position to spawn the particle 
			force: whether to show the particle if it's more than 32 blocks away 
			id: the particle id 
			speed: the speed of the particle 
		"""
		pass

	@overload
	def getRaw(self) -> ClientWorld:
		"""
		Since: 1.9.1 

		Returns:
			the raw minecraft world. 
		"""
		pass

	@overload
	def getServerInstantTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps. 
		"""
		pass

	@overload
	def getServer1MAverageTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps over the previous 1 minute average. 
		"""
		pass

	@overload
	def getServer5MAverageTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps over the previous 5 minute average. 
		"""
		pass

	@overload
	def getServer15MAverageTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps over the previous 15 minute average. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_PandaEntity = TypeVar("net_minecraft_entity_passive_PandaEntity")
PandaEntity = net_minecraft_entity_passive_PandaEntity


class PandaEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PandaEntity) -> None:
		pass

	@overload
	def getMainGene(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the id of this panda's main gene. 
		"""
		pass

	@overload
	def getMainGeneName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this panda's main gene. 
		"""
		pass

	@overload
	def isMainGeneRecessive(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's main gene is recessive, 'false' otherwise. 
		"""
		pass

	@overload
	def getHiddenGene(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the id of this panda's hidden gene. 
		"""
		pass

	@overload
	def getHiddenGeneName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this panda's hidden gene. 
		"""
		pass

	@overload
	def isHiddenGeneRecessive(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's hidden gene is recessive, 'false' otherwise. 
		"""
		pass

	@overload
	def isIdle(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda is idling, 'false' otherwise. 
		"""
		pass

	@overload
	def isSneezing(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda is currently sneezing, 'false' otherwise. 
		"""
		pass

	@overload
	def isPlaying(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda is playing, 'false' otherwise. 
		"""
		pass

	@overload
	def isSitting(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda is sitting, 'false' otherwise. 
		"""
		pass

	@overload
	def isLyingOnBack(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda is lying on its back, 'false' otherwise. 
		"""
		pass

	@overload
	def isLazy(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's genes make him lazy, 'false' otherwise. 
		"""
		pass

	@overload
	def isWorried(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's genes make him worried, 'false' otherwise. 
		"""
		pass

	@overload
	def isScaredByThunderstorm(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda is scared by an active thunderstorm, 'false' otherwise. 
		"""
		pass

	@overload
	def isPlayful(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's genes make him playful, 'false' otherwise. 
		"""
		pass

	@overload
	def isBrown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's genes make him brown, 'false' otherwise. 
		"""
		pass

	@overload
	def isWeak(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's genes make him weak, 'false' otherwise. 
		"""
		pass

	@overload
	def isAttacking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this panda's genes make him aggressive, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload


class Event:

	@overload
	def value(self) -> str:
		pass

	@overload
	def oldName(self) -> str:
		pass

	@overload
	def cancellable(self) -> bool:
		pass

	@overload
	def joinable(self) -> bool:
		pass

	@overload
	def filterer(self) -> Class:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID


class MixinFoxEntity:
	"""
	Since: 1.8.4 
	"""

	@overload
	def invokeIsAggressive(self) -> bool:
		pass

	@overload
	def invokeGetTrustedUuids(self) -> List[UUID]:
		pass

	pass





from typing import overload


class InteractionProxy:
	"""A class that can override crosshair target, handle breaking block and long interact.\n
	Since: 1.9.0 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def reset(self) -> None:
		pass

	pass





from typing import overload
from typing import List


class Sorting_MacroSortMethod:
	Enabled: "Sorting_MacroSortMethod"
	TriggerName: "Sorting_MacroSortMethod"
	FileName: "Sorting_MacroSortMethod"

	@overload
	def values(self) -> List["Sorting_MacroSortMethod"]:
		pass

	@overload
	def valueOf(self, name: str) -> "Sorting_MacroSortMethod":
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventChunkLoad(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	x: int
	z: int
	isFull: bool

	@overload
	def __init__(self, x: int, z: int, isFull: bool) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .ClickableWidgetHelper import ClickableWidgetHelper
from .MethodWrapper import MethodWrapper

net_minecraft_client_gui_widget_TextFieldWidget = TypeVar("net_minecraft_client_gui_widget_TextFieldWidget")
TextFieldWidget = net_minecraft_client_gui_widget_TextFieldWidget


class TextFieldWidgetHelper(ClickableWidgetHelper):
	"""
	Since: 1.0.5 
	"""

	@overload
	def __init__(self, t: TextFieldWidget) -> None:
		pass

	@overload
	def __init__(self, t: TextFieldWidget, zIndex: int) -> None:
		pass

	@overload
	def getText(self) -> str:
		"""
		Since: 1.0.5 

		Returns:
			the currently entered String . 
		"""
		pass

	@overload
	def setText(self, text: str) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			text: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setText(self, text: str, await_: bool) -> "TextFieldWidgetHelper":
		"""set the currently entered String .\n
		Since: 1.3.1 

		Args:
			await: 
			text: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setEditableColor(self, color: int) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			color: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setEditable(self, edit: bool) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			edit: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isEditable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the text field is editable, 'false' otherwise. 
		"""
		pass

	@overload
	def setUneditableColor(self, color: int) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			color: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSelectedText(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the selected text. 
		"""
		pass

	@overload
	def setSuggestion(self, suggestion: str) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			suggestion: the suggestion to set 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMaxLength(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum length of this text field. 
		"""
		pass

	@overload
	def setMaxLength(self, length: int) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			length: the new maximum length 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setSelection(self, start: int, end: int) -> "TextFieldWidgetHelper":
		pass

	@overload
	def setTextPredicate(self, predicate: MethodWrapper) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			predicate: the text filter 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def resetTextPredicate(self) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCursorPosition(self, position: int) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			position: the cursor position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCursorPosition(self, position: int, shift: bool) -> "TextFieldWidgetHelper":
		"""
		Since: 1.9.0 

		Returns:
			the cursor position. 
		"""
		pass

	@overload
	def setCursorToStart(self) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCursorToStart(self, shift: bool) -> "TextFieldWidgetHelper":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCursorToEnd(self) -> "TextFieldWidgetHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCursorToEnd(self, shift: bool) -> "TextFieldWidgetHelper":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RunningContextContainer import RunningContextContainer

java_util_Comparator_xyz_wagyourtail_jsmacros_client_gui_containers_RunningContextContainer_ = TypeVar("java_util_Comparator_xyz_wagyourtail_jsmacros_client_gui_containers_RunningContextContainer_")
Comparator = java_util_Comparator_xyz_wagyourtail_jsmacros_client_gui_containers_RunningContextContainer_


class CancelScreen_RTCSort(Comparator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, arg0: RunningContextContainer, arg1: RunningContextContainer) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement import RenderElement
from .Alignable import Alignable
from .IDraw2D import IDraw2D
from .TextHelper import TextHelper

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class Text(RenderElement, Alignable):
	"""
	Since: 1.0.5 
	"""
	parent: IDraw2D
	text: Text
	scale: float
	rotation: float
	rotateCenter: bool
	x: int
	y: int
	color: int
	width: int
	shadow: bool
	zIndex: int

	@overload
	def __init__(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def __init__(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def setX(self, x: int) -> "Text":
		"""
		Since: 1.8.4 

		Args:
			x: the new x position for this text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of this element. 
		"""
		pass

	@overload
	def setY(self, y: int) -> "Text":
		"""
		Since: 1.8.4 

		Args:
			y: the new y position for this text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of this element. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> "Text":
		"""
		Since: 1.0.5 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def setText(self, text: str) -> "Text":
		"""
		Since: 1.0.5 

		Args:
			text: 
		"""
		pass

	@overload
	def setText(self, text: TextHelper) -> "Text":
		"""
		Since: 1.2.7 

		Args:
			text: 
		"""
		pass

	@overload
	def getText(self) -> TextHelper:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of this text. 
		"""
		pass

	@overload
	def setShadow(self, shadow: bool) -> "Text":
		"""
		Since: 1.8.4 

		Args:
			shadow: whether the text should be rendered with a shadow 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hasShadow(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this text element is rendered with a shadow, 'false' otherwise. 
		"""
		pass

	@overload
	def setScale(self, scale: float) -> "Text":
		"""
		Since: 1.0.5 

		Args:
			scale: 
		"""
		pass

	@overload
	def getScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of this text. 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "Text":
		"""
		Since: 1.0.5 

		Args:
			rotation: 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation of this text. 
		"""
		pass

	@overload
	def setRotateCenter(self, rotateCenter: bool) -> "Text":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether this text should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this text should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def setColor(self, color: int) -> "Text":
		"""
		Since: 1.8.4 

		Args:
			color: the new color for this text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of this text. 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> "Text":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the new z-index for this text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def render3D(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def setParent(self, parent: IDraw2D) -> "Text":
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Text":
		pass

	pass





from typing import overload
from typing import Mapping
from .BaseLibrary import BaseLibrary
from .HTTPRequest import HTTPRequest
from .HTTPRequest_Response import HTTPRequest_Response
from .Websocket import Websocket


class FRequest(BaseLibrary):
	"""Functions for getting and using raw java classes, methods and functions. 
An instance of this class is passed to scripts as the 'Request' variable.\n
	Since: 1.1.8 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def create(self, url: str) -> HTTPRequest:
		"""create a HTTPRequest handler to the specified URL\n
		Since: 1.1.8 

		Args:
			url: 

		Returns:
			Request Wrapper 
		"""
		pass

	@overload
	def get(self, url: str) -> HTTPRequest_Response:
		"""
		Since: 1.1.8 

		Args:
			url: 
		"""
		pass

	@overload
	def get(self, url: str, headers: Mapping[str, str]) -> HTTPRequest_Response:
		"""send a GET request to the specified URL.\n
		Since: 1.1.8 

		Args:
			headers: 
			url: 

		Returns:
			Response Data 
		"""
		pass

	@overload
	def post(self, url: str, data: str) -> HTTPRequest_Response:
		"""
		Since: 1.1.8 

		Args:
			data: 
			url: 
		"""
		pass

	@overload
	def post(self, url: str, data: str, headers: Mapping[str, str]) -> HTTPRequest_Response:
		"""send a POST request to the specified URL.\n
		Since: 1.1.8 

		Args:
			headers: 
			data: 
			url: 

		Returns:
			Response Data 
		"""
		pass

	@overload
	def createWS(self, url: str) -> Websocket:
		"""Create a Websocket handler.\n
		Since: 1.2.7 

		Args:
			url: 
		"""
		pass

	@overload
	def createWS2(self, url: str) -> Websocket:
		"""Create a Websocket handler.\n
		Since: 1.1.9 

		Args:
			url: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class TranslationUtil:
	"""
	Since: 1.6.4 
	"""

	@overload
	def getTranslatedEventName(self, eventName: str) -> Text:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_boss_WitherEntity = TypeVar("net_minecraft_entity_boss_WitherEntity")
WitherEntity = net_minecraft_entity_boss_WitherEntity


class WitherEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: WitherEntity) -> None:
		pass

	@overload
	def getRemainingInvulnerableTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the time in ticks the wither will be invulnerable for. 
		"""
		pass

	@overload
	def isInvulnerable(self) -> bool:
		"""The wither will only be invulnerable, by default for 220 ticks, when summoned.\n
		Since: 1.8.4 

		Returns:
			'true' if the wither is invulnerable, 'false' otherwise. 
		"""
		pass

	@overload
	def isFirstPhase(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the wither is in its first phase, 'false' otherwise. 
		"""
		pass

	@overload
	def isSecondPhase(self) -> bool:
		"""In the second phase the wither will be invulnerable to projectiles and starts going down
towards the player.\n
		Since: 1.8.4 

		Returns:
			'true' if the wither is in its second phase, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

net_minecraft_entity_decoration_DisplayEntity_TextDisplayEntity_Data = TypeVar("net_minecraft_entity_decoration_DisplayEntity_TextDisplayEntity_Data")
DisplayEntity_TextDisplayEntity_Data = net_minecraft_entity_decoration_DisplayEntity_TextDisplayEntity_Data


class TextDisplayEntityHelper_TextDisplayDataHelper(BaseHelper):

	@overload
	def __init__(self, base: DisplayEntity_TextDisplayEntity_Data) -> None:
		pass

	@overload
	def getText(self) -> TextHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLineWidth(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getTextOpacity(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getBackgroundColor(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def hasShadowFlag(self) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def hasSeeThroughFlag(self) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def hasDefaultBackgroundFlag(self) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getAlignment(self) -> str:
		"""
		Since: 1.9.1 

		Returns:
			"center", "left" or "right" 
		"""
		pass

	pass





from typing import overload
from typing import List
from .BaseEvent import BaseEvent


class EventResourcePackLoaded(BaseEvent):
	"""This event is fired after resources have been reloaded, i.e. after the splash screen has finished.
This includes when the game is finished loading and the title screen becomes visible, which you can check using EventResourcePackLoaded#isGameStart .\n
	Since: 1.5.1 
	"""
	isGameStart: bool
	loadedPacks: List[str]

	@overload
	def __init__(self, isGameStart: bool) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .ICategoryTreeParent import ICategoryTreeParent
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class SettingsOverlay(ICategoryTreeParent, OverlayContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: IOverlayParent) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def clearCategory(self) -> None:
		pass

	@overload
	def selectCategory(self, category: List[str]) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def onClose(self) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .LivingEntityHelper import LivingEntityHelper

net_minecraft_entity_decoration_ArmorStandEntity = TypeVar("net_minecraft_entity_decoration_ArmorStandEntity")
ArmorStandEntity = net_minecraft_entity_decoration_ArmorStandEntity


class ArmorStandEntityHelper(LivingEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: ArmorStandEntity) -> None:
		pass

	@overload
	def isVisible(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the armor stand is visible, 'false' otherwise. 
		"""
		pass

	@overload
	def isSmall(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the armor is small, 'false' otherwise. 
		"""
		pass

	@overload
	def hasArms(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the armor stand has arms, 'false' otherwise. 
		"""
		pass

	@overload
	def hasBasePlate(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the armor stand has a base plate, 'false' otherwise. 
		"""
		pass

	@overload
	def isMarker(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the armor stand is a marker, 'false' otherwise. 
		"""
		pass

	@overload
	def getHeadRotation(self) -> List[float]:
		"""The rotation is in the format of '[yaw, pitch, roll]' .\n
		Since: 1.8.4 

		Returns:
			the head rotation of the armor stand. 
		"""
		pass

	@overload
	def getBodyRotation(self) -> List[float]:
		"""The rotation is in the format of '[yaw, pitch, roll]' .\n
		Since: 1.8.4 

		Returns:
			the body rotation of the armor stand. 
		"""
		pass

	@overload
	def getLeftArmRotation(self) -> List[float]:
		"""The rotation is in the format of '[yaw, pitch, roll]' .\n
		Since: 1.8.4 

		Returns:
			the left arm rotation of the armor stand. 
		"""
		pass

	@overload
	def getRightArmRotation(self) -> List[float]:
		"""The rotation is in the format of '[yaw, pitch, roll]' .\n
		Since: 1.8.4 

		Returns:
			the right arm rotation of the armor stand. 
		"""
		pass

	@overload
	def getLeftLegRotation(self) -> List[float]:
		"""The rotation is in the format of '[yaw, pitch, roll]' .\n
		Since: 1.8.4 

		Returns:
			the left leg rotation of the armor stand. 
		"""
		pass

	@overload
	def getRightLegRotation(self) -> List[float]:
		"""The rotation is in the format of '[yaw, pitch, roll]' .\n
		Since: 1.8.4 

		Returns:
			the right leg rotation of the armor stand. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

T = TypeVar("T")

class BaseHelper(Generic[T]):

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def getRaw(self) -> T:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def equals(self, obj: object) -> bool:
		pass

	pass


